# Imagic

Uma biblioteca Python para manipulação de imagens, usando Pillow.

## Funcionalidades

- Redimensionamento de imagens
- Conversão para preto e branco
- Adição de texto em imagens
- Aplicação de filtros de desfoque e inversão de cores